@@ -25,7 +25,7 @@ import logging
 import simplejson
 
 from shutil import rmtree
-from urllib import unquote as decode
+from urllib import unquote
 
 from tiddlyweb import __version__ as TIDDLYWEB_VERSION
 from tiddlyweb.model.tiddler import Tiddler
@@ -43,11 +43,12 @@ from tiddlyweb.util import read_utf8_file, write_utf8_file
 from tiddlywebplugins.twimport import url_to_tiddler
 
 
-__version__ = "0.7.0"
+__version__ = "0.7.7"
 
 # XXX: should be class attributes?
 RECIPE_EXT = ".recipe"
 TIDDLER_EXT = ".tid"
+PLUGIN_EXT = ".js"
 USER_EXT = ".user"
 
 
@@ -161,10 +162,6 @@ class Store(StorageInterface):
 		tiddler_path = self._tiddler_path(tiddler)
 		tiddler.revision = 1
 
-		if (tiddler.type and tiddler.type != "None" and
-			not tiddler.type.startswith("text/")):
-			tiddler.text = b64encode(tiddler.text)
-
 		self.serializer.object = tiddler
 		write_utf8_file(tiddler_path, self.serializer.to_string())
 
@@ -217,12 +214,12 @@ class Store(StorageInterface):
 
 	def list_recipes(self):
 		logging.debug("list recipes")
-		return (Recipe(filename[:-7]) for filename in os.listdir(self._root)
-			if filename.endswith(RECIPE_EXT))
+		return (Recipe(decode(filename[:-7])) for filename in
+			os.listdir(self._root) if filename.endswith(RECIPE_EXT))
 
 	def list_bags(self):
 		logging.debug("list bags")
-		locals = [dirname for dirname in os.listdir(self._root)
+		locals = [decode(dirname) for dirname in os.listdir(self._root)
 			if os.path.isdir(os.path.join(self._root, dirname))]
 		remotes = [bag_name for bag_name in self._index]
 		names = set(locals).union(remotes)
@@ -230,8 +227,8 @@ class Store(StorageInterface):
 
 	def list_users(self):
 		logging.debug("list users")
-		return (User(filename[:-5]) for filename in os.listdir(self._root)
-			if filename.endswith(USER_EXT))
+		return (User(decode(filename[:-5])) for filename in
+			os.listdir(self._root) if filename.endswith(USER_EXT))
 
 	def list_bag_tiddlers(self, bag):
 		bag_path = self._bag_path(bag)
@@ -265,7 +262,10 @@ class Store(StorageInterface):
 				for field in tiddler.fields:
 					if query in tiddler.fields[field]:
 						yield tiddler
-				if query in tiddler.text:
+				if ((tiddler.type == 'None'
+				    or tiddler.type == None
+				    or tiddler.type.startswith('text/'))
+				    and query in tiddler.text):
 					yield tiddler
 
 	def _write_description(self, desc, base_path):
@@ -368,7 +368,8 @@ def _expand_recipe(uri):
 	uris = []
 	for rule in rules:
 		type, uri = rule.split(": ")
-		uri = os.path.join(base_dir, uri)
+		if not uri.startswith("http") and not uri.startswith("https"):
+			uri = os.path.join(base_dir, uri)
 		if type == "recipe":
 			uris = uris + _expand_recipe(uri)
 		else:
@@ -381,10 +382,19 @@ def _extract_title(uri):
 	"""
 	determine title from file path
 	"""
-	return uri.split("/")[-1].rsplit(".", 1)[0]
+	filename = uri.split("/")[-1]
+	name, ext = filename.rsplit(".", 1)
+	if ".%s" % ext in [TIDDLER_EXT, PLUGIN_EXT]:
+		return name
+	else:
+		return filename
 
 
 def _read_file(uri):
 	if uri.startswith("file://"): # XXX: hack; use twimport's _get_url_handle!?
 		uri = uri[7:]
 	return read_utf8_file(uri)
+
+
+def decode(name):
+	return unicode(unquote(name), "utf-8")
